@@ -18,4 +18,11 @@ class AnalogicMap:
         _value_map = (
             (x-in_min)*(out_max-out_min)/(in_max - in_min)+out_min
         )
-        return _value_map if self._return_float else int(_value_map)
\ No newline at end of file
+        return _value_map if self._return_float else int(_value_map)
+
+def hex_to_rgb(value):
+        _value = value.strip().replace('#', '')
+        _rgb = len(_value)
+        if _rgb != 6:
+            raise ValueError(f'The hex color #{value} is not valid')
+        return tuple(int(_value[i:i+_rgb//3], 16) for i in range(0, _rgb, _rgb//3))
